/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.geronimo.webservices.jaxr;

import org.apache.geronimo.gbean.GBeanInfo;
import org.apache.geronimo.gbean.GBeanInfoBuilder;
import org.apache.geronimo.j2ee.j2eeobjectnames.NameFactory;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.logging.Log;

import javax.xml.registry.ConnectionFactory;
import javax.xml.registry.JAXRException;

/**
 * Simple GBean to provide access to a JAXR ConnectionFactory
 *
 * @version $Rev: 486195 $ $Date: 2006-12-12 07:42:02 -0800 (Tue, 12 Dec 2006) $
 */
public class JAXRGBean {

    private final Log log = LogFactory.getLog(JAXRGBean.class);
    private final ClassLoader cl;
    private final String connectionFactoryClass;

    public JAXRGBean(String connectionFactoryClass, ClassLoader cl) {
        this.cl = cl;
        this.connectionFactoryClass = connectionFactoryClass;
    }

    /**
     * Returns a fresh, new implementation of javax.xml.registry.ConnectionFactory
     *
     * @return ConnectionFactory
     */
    public Object $getResource() {
        if (connectionFactoryClass != null) {
            System.setProperty("javax.xml.registry.ConnectionFactoryClass", connectionFactoryClass);
            //TODO consider whether we should bypass the code below and just construct it ourselves, like it does.
        }
        Thread currentThread = Thread.currentThread();
        ClassLoader oldCl = currentThread.getContextClassLoader();
        currentThread.setContextClassLoader(cl);
        try {
            return ConnectionFactory.newInstance();
        } catch (JAXRException e) {
            log.error("Error creating ConnectionFactory", e);
        } finally {
            currentThread.setContextClassLoader(oldCl);
        }

        return null;
    }


    public static final GBeanInfo GBEAN_INFO;

    static {
        GBeanInfoBuilder infoFactory = GBeanInfoBuilder.createStatic(JAXRGBean.class,
                NameFactory.JAXR_CONNECTION_FACTORY);

        infoFactory.addAttribute("connectionFactoryClass", String.class, true, true);
        infoFactory.addAttribute("classLoader", ClassLoader.class, false);

        infoFactory.addOperation("$getResource");

        infoFactory.setConstructor(new String[] {"connectionFactoryClass", "classLoader"});

        GBEAN_INFO = infoFactory.getBeanInfo();
    }

    public static GBeanInfo getGBeanInfo() {
        return GBEAN_INFO;
    }


}
